@@ -5,7 +5,7 @@ from typing import List, Union
 from pathlib import Path
 
 
-__version__ = "2022.5.16.3"
+__version__ = "2022.5.27.1"
 log_format = logging.Formatter(
     "[%(asctime)s] %(filename)s/%(lineno)s/%(funcName)s/%(levelname)s: %(message)s"
 )
@@ -52,13 +52,19 @@ def configure_logger(
     handlers: List[logging.Handler] = None,
     log_file: Union[Path, str] = None,
     append: bool = True,
+    caller_info: dict = None,
 ):
     """配置日志处理器
     :param level: int, 指定日志级别
     :param handlers: List[Handler], 日志处理器列表
     :param log_file: 日志文件存储路径
     :param append: 是否为追加模式。当为覆盖模式时会清空已有的handler再添加新的
+    :param caller_info: 调用源信息
     """
+    from deng.utils import get_caller_info
+    _info = caller_info or get_caller_info(2)
+    logger.info(f"调用来源：{_info['output']}")
+
     # 设置日志级别
     if level in (
         logging.NOTSET,
