@@ -238,7 +238,17 @@ def pull_repo(
             else:
                 logger.warning(f"仓库{repo_path}分支{branch}与上游{remote}/{branch}分支不一致")
     elif branch_type == "tag":
-        utils.execute_cmd(["git", "fetch", "--tag"], level="debug")
+        try:
+            # 拉取指定tag或是本地不存在但远程存在的tag
+            # 已有的tag不会对比，防止本地已有tag与远程相应tag不一致时出现冲突报错
+            utils.execute_cmd(["git", "fetch", remote, "tag", branch], level="debug")
+        except Exception as _err:
+            logger.exception(_err)
+            logger.error(f"拉取tag {branch}出错，删除本地{branch}后重试")
+            # 出错后——通常是本地与远程tag不一致有冲突导致的
+            # 冲突后删除本地重新从远程拉取
+            utils.execute_cmd(["git", "tag", "-d", branch], level="debug")
+            utils.execute_cmd(["git", "fetch", remote, "tag", branch], level="debug")
         utils.execute_cmd(["git", "checkout", branch], level="debug")
     elif branch_type == "commit":
         # 先检查本地是否已经为预计目标，如果是则不用访问远程git服务，防止远程git服务不可用导致额外的报错
