@@ -137,17 +137,7 @@ class MyJSONEncoder(json.encoder.JSONEncoder):
     """自定义JSON序列化类"""
 
     def default(self, o):
-        if isinstance(o, datetime.datetime):
-            return o.strftime("%Y-%m-%d %H:%M:%S")
-        if isinstance(o, datetime.date):
-            return o.strftime("%Y-%m-%d")
-        if isinstance(o, uuid.UUID):
-            return str(o)
-        if hasattr(o, "__html__"):
-            return str(o.__html__())
-        raise TypeError(
-            f"Object of type {o.__class__.__name__} " f"is not JSON serializable"
-        )
+        return my_json_serializable(o)
 
 
 def byte_to_str(src, encoding=None) -> str:
